@@ -48,8 +48,7 @@ describe('SMTP-Connection Tests', function() {
                 onData: function(stream, session, callback) {
                     stream.on('data', function() {});
                     stream.on('end', callback);
-                },
-                logger: false
+                }
             });
 
             insecureServer = new SMTPServer({
@@ -214,7 +213,7 @@ describe('SMTP-Connection Tests', function() {
             client.on('end', done);
         });
 
-        it('should receive end after STARTTLS', function(done) {
+        it('should close connection after STARTTLS', function(done) {
             let client = new SMTPConnection({
                 port: PORT_NUMBER,
                 logger: false
@@ -228,7 +227,7 @@ describe('SMTP-Connection Tests', function() {
             });
 
             client.on('error', function(err) {
-                expect(err).to.not.exist;
+                expect(err.message).to.equal('Connection closed unexpectedly');
             });
 
             client.on('end', done);
@@ -1317,32 +1316,28 @@ describe('SMTP-Connection Tests', function() {
 });
 
 function proxyConnect(port, host, destinationPort, destinationHost, callback) {
-    let socket = net.connect(
-        port,
-        host,
-        function() {
-            socket.write('CONNECT ' + destinationHost + ':' + destinationPort + ' HTTP/1.1\r\n\r\n');
+    let socket = net.connect(port, host, function() {
+        socket.write('CONNECT ' + destinationHost + ':' + destinationPort + ' HTTP/1.1\r\n\r\n');
 
-            let headers = '';
-            let onSocketData = function(chunk) {
-                let match;
-                let remainder;
+        let headers = '';
+        let onSocketData = function(chunk) {
+            let match;
+            let remainder;
 
-                headers += chunk.toString('binary');
-                if ((match = headers.match(/\r\n\r\n/))) {
-                    socket.removeListener('data', onSocketData);
-                    remainder = headers.substr(match.index + match[0].length);
-                    headers = headers.substr(0, match.index);
-                    if (remainder) {
-                        socket.unshift(Buffer.from(remainder, 'binary'));
-                    }
-                    // proxy connection is now established
-                    return callback(null, socket);
+            headers += chunk.toString('binary');
+            if ((match = headers.match(/\r\n\r\n/))) {
+                socket.removeListener('data', onSocketData);
+                remainder = headers.substr(match.index + match[0].length);
+                headers = headers.substr(0, match.index);
+                if (remainder) {
+                    socket.unshift(Buffer.from(remainder, 'binary'));
                 }
-            };
-            socket.on('data', onSocketData);
-        }
-    );
+                // proxy connection is now established
+                return callback(null, socket);
+            }
+        };
+        socket.on('data', onSocketData);
+    });
 
     socket.on('error', function(err) {
         expect(err).to.not.exist;
